@@ -69,7 +69,9 @@ public:
         /// Tangent (X axis if normal is Z)
         SPS_TANGENT = 9,
         /// VFACE
-        SPS_FRONT_FACING
+        SPS_FRONT_FACING,
+        /// SV_RenderTargetArrayIndex
+        SPS_LAYER
     };
 
     /** Shader parameter content
@@ -180,6 +182,9 @@ public:
         /// gl_FrontFacing
         SPC_FRONT_FACING,
 
+        /// gl_Layer
+        SPC_LAYER,
+
         /// Reserved custom content range to be used by user custom shader extensions.
         SPC_CUSTOM_CONTENT_BEGIN    = 1000,
         SPC_CUSTOM_CONTENT_END      = 2000
@@ -198,9 +203,8 @@ public:
     @param content The content of this parameter.
     @param size
     */
-    Parameter(GpuConstantType type, const String& name, 
-        const Semantic& semantic, int index, 
-        const Content& content, size_t size = 0);
+    Parameter(GpuConstantType type, const String& name, const Semantic& semantic, int index, int content,
+              size_t size = 0);
 
     /** Class destructor */
     virtual ~Parameter() {};
@@ -226,7 +230,7 @@ public:
     int getIndex() const { return mIndex; } 
 
     /** Return the content of this parameter. */
-    Content getContent() const { return mContent; }
+    int getContent() const { return mContent; }
 
     /** Returns true if this instance is a ConstParameter otherwise false. */
     virtual bool isConstParameter() const { return false; }
@@ -273,7 +277,7 @@ protected:
     // Index of this parameter.
     int mIndex;
     // The content of this parameter.
-    Content mContent;
+    int mContent;
     // Number of elements in the parameter (for arrays)
     size_t mSize;
     
@@ -301,7 +305,7 @@ public:
     */
     UniformParameter(GpuConstantType type, const String& name, 
         const Semantic& semantic, int index, 
-        const Content& content,
+        int content,
         uint16 variability, size_t size);
 
     /** Class constructor.
@@ -551,7 +555,7 @@ class _OgreRTSSExport ParameterFactory
     // Interface.
 public:
 
-    static ParameterPtr createInPosition(int index, Parameter::Content content = Parameter::SPC_POSITION_OBJECT_SPACE);
+    static ParameterPtr createInPosition(int index, int content = Parameter::SPC_POSITION_OBJECT_SPACE);
     static ParameterPtr createOutPosition(int index);
 
     static ParameterPtr createInNormal(int index);
@@ -565,8 +569,8 @@ public:
     static ParameterPtr createInColor(int index);
     static ParameterPtr createOutColor(int index);
 
-    static ParameterPtr createInTexcoord(GpuConstantType type, int index, Parameter::Content content);
-    static ParameterPtr createOutTexcoord(GpuConstantType type, int index, Parameter::Content content);
+    static ParameterPtr createInTexcoord(GpuConstantType type, int index, int content);
+    static ParameterPtr createOutTexcoord(GpuConstantType type, int index, int content);
 
     static ParameterPtr createConstParam(const Vector2& val);
     static ParameterPtr createConstParam(const Vector3& val);
