@@ -47,13 +47,12 @@ namespace Ogre
         assignment of a vertex to a bone for skeletal animation. There may be many of these
         per vertex if blended vertex assignments are allowed.
     */
-    typedef struct VertexBoneAssignment_s
+    struct VertexBoneAssignment
     {
-        unsigned int vertexIndex;
-        unsigned short boneIndex;
-        Real weight;
-
-    } VertexBoneAssignment;
+        uint32 vertexIndex;
+        uint16 boneIndex;
+        float weight;
+    };
 
     /** @} */
     /** @} */
