@@ -194,7 +194,7 @@ namespace Ogre
 
     void ScriptCompilerListener::preConversion(ScriptCompiler *compiler, ConcreteNodeListPtr nodes)
     {
-        
+
     }
 
     bool ScriptCompilerListener::postConversion(ScriptCompiler *compiler, const AbstractNodeListPtr &nodes)
@@ -208,7 +208,7 @@ namespace Ogre
         ss << "ScriptCompiler - " << ScriptCompiler::formatErrorCode(code) << " in " << file << "(" << line << ")";
         if(!msg.empty())
             ss << ": " << msg;
-        
+
         if(code == ScriptCompiler::CE_DEPRECATEDSYMBOL)
             LogManager::getSingleton().logWarning(ss.str());
         else
@@ -287,10 +287,10 @@ namespace Ogre
             {
                 PropertyAbstractNode *prop = static_cast<PropertyAbstractNode*>(node.get());
                 msg = msg + prop->name + " =";
-                for(AbstractNodeList::iterator i = prop->values.begin(); i != prop->values.end(); ++i)
+                for(const auto& v : prop->values)
                 {
-                    if((*i)->type == ANT_ATOM)
-                        msg = msg + " " + static_cast<AtomAbstractNode*>((*i).get())->value;
+                    if(v->type == ANT_ATOM)
+                        msg = msg + " " + static_cast<AtomAbstractNode*>(v.get())->value;
                 }
             }
             break;
@@ -298,10 +298,10 @@ namespace Ogre
             {
                 ObjectAbstractNode *obj = static_cast<ObjectAbstractNode*>(node.get());
                 msg = msg + node->file + " - " + StringConverter::toString(node->line) + " - " + obj->cls + " \"" + obj->name + "\" =";
-                for(AbstractNodeList::iterator i = obj->values.begin(); i != obj->values.end(); ++i)
+                for(const auto& v : obj->values)
                 {
-                    if((*i)->type == ANT_ATOM)
-                        msg = msg + " " + static_cast<AtomAbstractNode*>((*i).get())->value;
+                    if(v->type == ANT_ATOM)
+                        msg = msg + " " + static_cast<AtomAbstractNode*>(v.get())->value;
                 }
             }
             break;
@@ -314,9 +314,9 @@ namespace Ogre
         if(node->type == ANT_OBJECT)
         {
             ObjectAbstractNode *obj = static_cast<ObjectAbstractNode*>(node.get());
-            for(AbstractNodeList::iterator i = obj->children.begin(); i != obj->children.end(); ++i)
+            for(const auto& c : obj->children)
             {
-                logAST(tabs + 1, *i);
+                logAST(tabs + 1, c);
             }
         }
     }
@@ -324,6 +324,11 @@ namespace Ogre
 
     bool ScriptCompiler::compile(const ConcreteNodeListPtr &nodes, const String &group)
     {
+        if(nodes && !nodes->empty())
+        {
+            mSourceFile = nodes->front()->file;
+        }
+
         // Set up the compilation context
         mGroup = group;
 
@@ -348,12 +353,12 @@ namespace Ogre
         // Allows early bail-out through the listener
         if(mListener && !mListener->postConversion(this, ast))
             return mErrors.empty();
-        
+
         // Translate the nodes
         for(auto & i : *ast)
         {
 #if DEBUG_AST
-            logAST(0, *i);
+            logAST(0, i);
 #endif
             if(i->type == ANT_OBJECT && static_cast<ObjectAbstractNode*>(i.get())->abstract)
                 continue;
@@ -366,6 +371,7 @@ namespace Ogre
         mImports.clear();
         mImportRequests.clear();
         mImportTable.clear();
+        mSourceFile.clear();
 
         return mErrors.empty();
     }
@@ -385,6 +391,11 @@ namespace Ogre
         mErrors.push_back({file, msg, line, code});
     }
 
+    void ScriptCompiler::addError(const AbstractNode& node, const String& msg, uint32 code)
+    {
+        addError(code, mSourceFile, node.line, msg);
+    }
+
     void ScriptCompiler::setListener(ScriptCompilerListener *listener)
     {
         mListener = listener;
@@ -528,7 +539,7 @@ namespace Ogre
     AbstractNodeList ScriptCompiler::locateTarget(const AbstractNodeList& nodes, const Ogre::String &target)
     {
         SharedPtr<AbstractNode> iter = nullptr;
-    
+
         // Search for a top-level object node
         for(auto i : nodes)
         {
@@ -914,6 +925,8 @@ namespace Ogre
         mIds["tessellation_hull_program"] = ID_TESSELLATION_HULL_PROGRAM;
         mIds["tessellation_domain_program"] = ID_TESSELLATION_DOMAIN_PROGRAM;
         mIds["compute_program"] = ID_COMPUTE_PROGRAM;
+        mIds["mesh_program"] = ID_MESH_PROGRAM;
+        mIds["task_program"] = ID_TASK_PROGRAM;
         mIds["technique"] = ID_TECHNIQUE;
         mIds["pass"] = ID_PASS;
         mIds["texture_unit"] = ID_TEXTURE_UNIT;
@@ -923,6 +936,8 @@ namespace Ogre
         mIds["tessellation_hull_program_ref"] = ID_TESSELLATION_HULL_PROGRAM_REF;
         mIds["tessellation_domain_program_ref"] = ID_TESSELLATION_DOMAIN_PROGRAM_REF;
         mIds["compute_program_ref"] = ID_COMPUTE_PROGRAM_REF;
+        mIds["mesh_program_ref"] = ID_MESH_PROGRAM_REF;
+        mIds["task_program_ref"] = ID_TASK_PROGRAM_REF;
         mIds["shadow_caster_vertex_program_ref"] = ID_SHADOW_CASTER_VERTEX_PROGRAM_REF;
         mIds["shadow_caster_fragment_program_ref"] = ID_SHADOW_CASTER_FRAGMENT_PROGRAM_REF;
         mIds["shadow_receiver_vertex_program_ref"] = ID_SHADOW_RECEIVER_VERTEX_PROGRAM_REF;
@@ -1001,7 +1016,6 @@ namespace Ogre
         mIds["cull_software"] = ID_CULL_SOFTWARE;
         mIds["back"] = ID_BACK;
         mIds["front"] = ID_FRONT;
-        mIds["normalise_normals"] = ID_NORMALISE_NORMALS;
         mIds["lighting"] = ID_LIGHTING;
         mIds["shading"] = ID_SHADING;
         mIds["flat"] = ID_FLAT;
@@ -1042,7 +1056,8 @@ namespace Ogre
         mIds["3d"] = ID_3D;
         mIds["cubic"] = ID_CUBIC;
         mIds["unlimited"] = ID_UNLIMITED;
-        mIds["2darray"] = ID_2DARRAY;
+        mIds["2darray"] = ID_2DARRAY; // deprecated and undocumented
+        mIds["2d_array"] = ID_2DARRAY;
         mIds["alpha"] = ID_ALPHA;
         mIds["gamma"] = ID_GAMMA;
         mIds["anim_texture"] = ID_ANIM_TEXTURE;
@@ -1113,9 +1128,6 @@ namespace Ogre
         mIds["square"] = ID_SQUARE;
         mIds["inverse_sawtooth"] = ID_INVERSE_SAWTOOTH;
         mIds["transform"] = ID_TRANSFORM;
-        mIds["binding_type"] = ID_BINDING_TYPE;
-        mIds["vertex"] = ID_VERTEX;
-        mIds["fragment"] = ID_FRAGMENT;
         mIds["geometry"] = ID_GEOMETRY;
         mIds["tessellation_hull"] = ID_TESSELLATION_HULL;
         mIds["tessellation_domain"] = ID_TESSELLATION_DOMAIN;
@@ -1148,6 +1160,7 @@ namespace Ogre
         mIds["pooled"] = ID_POOLED;
         //mIds["gamma"] = ID_GAMMA; - already registered
         mIds["no_fsaa"] = ID_NO_FSAA;
+        mIds["fsaa"] = ID_FSAA;
         mIds["depth_pool"] = ID_DEPTH_POOL;
 
         mIds["texture_ref"] = ID_TEXTURE_REF;
@@ -1155,7 +1168,7 @@ namespace Ogre
         mIds["chain_scope"] = ID_SCOPE_CHAIN;
         mIds["global_scope"] = ID_SCOPE_GLOBAL;
         mIds["compositor_logic"] = ID_COMPOSITOR_LOGIC;
-            
+
         mIds["only_initial"] = ID_ONLY_INITIAL;
         mIds["visibility_mask"] = ID_VISIBILITY_MASK;
         mIds["lod_bias"] = ID_LOD_BIAS;
@@ -1255,7 +1268,7 @@ namespace Ogre
             ImportAbstractNode *impl = OGRE_NEW ImportAbstractNode();
             impl->line = node->line;
             impl->file = node->file;
-            
+
             ConcreteNodeList::iterator iter = node->children.begin();
             impl->target = (*iter)->token;
 
@@ -1349,14 +1362,14 @@ namespace Ogre
                 if(node->token == "abstract")
                 {
                     impl->abstract = true;
-                    for(ConcreteNodeList::const_iterator i = node->children.begin(); i != node->children.end(); ++i)
-                        temp.push_back((*i).get());
+                    for(const auto& c : node->children)
+                        temp.push_back(c.get());
                 }
                 else
                 {
                     temp.push_back(node);
-                    for(ConcreteNodeList::const_iterator i = node->children.begin(); i != node->children.end(); ++i)
-                        temp.push_back((*i).get());
+                    for(const auto& c : node->children)
+                        temp.push_back(c.get());
                 }
 
                 // Get the type of object
@@ -1378,7 +1391,7 @@ namespace Ogre
 
                 // Get the name
                 // Unless the type is in the exclusion list
-                if(iter != temp.end() && ((*iter)->type == CNT_WORD || (*iter)->type == CNT_QUOTE) &&
+                if(iter != temp.end() && ((*iter)->type == CNT_WORD || (*iter)->type == CNT_QUOTE || (*iter)->type == CNT_VARIABLE) &&
                     !mCompiler->isNameExcluded(*impl, mCurrent))
                 {
                     impl->name = (*iter)->token;
@@ -1467,6 +1480,12 @@ namespace Ogre
                 impl->id = iter2->second;
 
             asn = AbstractNodePtr(impl);
+
+            if(mCurrent && mCurrent->type != ANT_PROPERTY)
+            {
+                // stray atom outside of a property is likely a property without a value
+                mCompiler->addError(*impl, "missing property value");
+            }
         }
 
         // Here, we must insert the node into the tree
@@ -1497,19 +1516,19 @@ namespace Ogre
         for(const auto & node : nodes)
             visitor->visit(node.get());
     }
-    
+
 
     // ScriptCompilerManager
     template<> ScriptCompilerManager *Singleton<ScriptCompilerManager>::msSingleton = 0;
-    
+
     ScriptCompilerManager* ScriptCompilerManager::getSingletonPtr(void)
     {
         return msSingleton;
     }
     //-----------------------------------------------------------------------
     ScriptCompilerManager& ScriptCompilerManager::getSingleton(void)
-    {  
-        assert( msSingleton );  return ( *msSingleton );  
+    {
+        assert( msSingleton );  return ( *msSingleton );
     }
     //-----------------------------------------------------------------------
     ScriptCompilerManager::ScriptCompilerManager()
@@ -1551,7 +1570,7 @@ namespace Ogre
     void ScriptCompilerManager::removeTranslatorManager(Ogre::ScriptTranslatorManager *man)
     {
             OGRE_LOCK_AUTO_MUTEX;
-        
+
         for(std::vector<ScriptTranslatorManager*>::iterator i = mManagers.begin(); i != mManagers.end(); ++i)
         {
             if(*i == man)
@@ -1572,7 +1591,7 @@ namespace Ogre
         ScriptTranslator *translator = 0;
         {
                     OGRE_LOCK_AUTO_MUTEX;
-            
+
             // Start looking from the back
             for(std::vector<ScriptTranslatorManager*>::reverse_iterator i = mManagers.rbegin(); i != mManagers.rend(); ++i)
             {
@@ -1616,8 +1635,6 @@ namespace Ogre
         }
     }
 
-    //-------------------------------------------------------------------------
-    String PreApplyTextureAliasesScriptCompilerEvent::eventType = "preApplyTextureAliases";
     //-------------------------------------------------------------------------
     String ProcessResourceNameScriptCompilerEvent::eventType = "processResourceName";
     //-------------------------------------------------------------------------
