@@ -27,10 +27,8 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 #include "OgreStaticGeometry.h"
-#include "OgreEntity.h"
 #include "OgreEdgeListBuilder.h"
 #include "OgreLodStrategy.h"
-#include "OgreSubEntity.h"
 
 namespace Ogre {
 
@@ -383,8 +381,8 @@ namespace Ogre {
             id->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT;
         IndexRemap indexRemap;
         HardwareBufferLockGuard indexLock(id->indexBuffer,
-                                          id->indexStart * id->indexBuffer->getIndexSize(), 
-                                          id->indexCount * id->indexBuffer->getIndexSize(), 
+                                          id->indexStart * id->indexBuffer->getIndexSize(),
+                                          id->indexCount * id->indexBuffer->getIndexSize(),
                                           HardwareBuffer::HBL_READ_ONLY);
         if (use32bitIndexes)
         {
@@ -457,8 +455,8 @@ namespace Ogre {
                 HardwareBuffer::HBU_STATIC);
 
         HardwareBufferLockGuard srcIndexLock(id->indexBuffer,
-                                             id->indexStart * id->indexBuffer->getIndexSize(), 
-                                             id->indexCount * id->indexBuffer->getIndexSize(), 
+                                             id->indexStart * id->indexBuffer->getIndexSize(),
+                                             id->indexCount * id->indexBuffer->getIndexSize(),
                                              HardwareBuffer::HBL_READ_ONLY);
         HardwareBufferLockGuard dstIndexLock(ibuf, HardwareBuffer::HBL_DISCARD);
         if (use32bitIndexes)
@@ -498,7 +496,7 @@ namespace Ogre {
 
         for (auto mobj : node->getAttachedObjects())
         {
-            if (mobj->getMovableType() == "Entity")
+            if (mobj->getMovableType() == MOT_ENTITY)
             {
                 addEntity(static_cast<Entity*>(mobj),
                     node->_getDerivedPosition(),
@@ -535,7 +533,7 @@ namespace Ogre {
         for (auto & ri : mRegionMap)
         {
             ri.second->build(stencilShadows);
-            
+
             // Set the visibility flags on these regions
             ri.second->setVisibilityFlags(mVisibilityFlags);
         }
@@ -618,10 +616,9 @@ namespace Ogre {
     void StaticGeometry::setVisibilityFlags(uint32 flags)
     {
         mVisibilityFlags = flags;
-        for (RegionMap::const_iterator ri = mRegionMap.begin();
-            ri != mRegionMap.end(); ++ri)
+        for (const auto& r : mRegionMap)
         {
-            ri->second->setVisibilityFlags(flags);
+            r.second->setVisibilityFlags(flags);
         }
     }
     //--------------------------------------------------------------------------
@@ -634,26 +631,26 @@ namespace Ogre {
         return ri->second->getVisibilityFlags();
     }
     //--------------------------------------------------------------------------
-    void StaticGeometry::dump(const String& filename) const
+    std::ostream& operator<<(std::ostream& o, const StaticGeometry& g)
     {
-        std::ofstream of(filename.c_str());
-        of << "Static Geometry Report for " << mName << std::endl;
-        of << "-------------------------------------------------" << std::endl;
-        of << "Number of queued submeshes: " << mQueuedSubMeshes.size() << std::endl;
-        of << "Number of regions: " << mRegionMap.size() << std::endl;
-        of << "Region dimensions: " << mRegionDimensions << std::endl;
-        of << "Origin: " << mOrigin << std::endl;
-        of << "Max distance: " << mUpperDistance << std::endl;
-        of << "Casts shadows?: " << mCastShadows << std::endl;
-        of << std::endl;
-        for (auto ri : mRegionMap)
+        o << "Static Geometry Report for " << g.mName << std::endl;
+        o << "-------------------------------------------------" << std::endl;
+        o << "Number of queued submeshes: " << g.mQueuedSubMeshes.size() << std::endl;
+        o << "Number of regions: " << g.mRegionMap.size() << std::endl;
+        o << "Region dimensions: " << g.mRegionDimensions << std::endl;
+        o << "Origin: " << g.mOrigin << std::endl;
+        o << "Max distance: " << g.mUpperDistance << std::endl;
+        o << "Casts shadows?: " << g.mCastShadows << std::endl;
+        o << std::endl;
+        for (auto ri : g.mRegionMap)
         {
-            ri.second->dump(of);
+            o << *ri.second;
         }
-        of << "-------------------------------------------------" << std::endl;
+        o << "-------------------------------------------------" << std::endl;
+        return o;
     }
     //---------------------------------------------------------------------
-    void StaticGeometry::visitRenderables(Renderable::Visitor* visitor, 
+    void StaticGeometry::visitRenderables(Renderable::Visitor* visitor,
         bool debugRenderables)
     {
         for (RegionMap::const_iterator ri = mRegionMap.begin();
@@ -791,8 +788,7 @@ namespace Ogre {
     //--------------------------------------------------------------------------
     const String& StaticGeometry::Region::getMovableType(void) const
     {
-        static String sType = "StaticGeometry";
-        return sType;
+        return MOT_STATIC_GEOMETRY;
     }
     //--------------------------------------------------------------------------
     void StaticGeometry::Region::_notifyCurrentCamera(Camera* cam)
@@ -851,7 +847,7 @@ namespace Ogre {
             mLodValue);
     }
     //---------------------------------------------------------------------
-    void StaticGeometry::Region::visitRenderables(Renderable::Visitor* visitor, 
+    void StaticGeometry::Region::visitRenderables(Renderable::Visitor* visitor,
         bool debugRenderables)
     {
         for (auto & i : mLodBucketList)
@@ -912,20 +908,21 @@ namespace Ogre {
         return mLodBucketList[mCurrentLod]->getEdgeList();
     }
     //--------------------------------------------------------------------------
-    void StaticGeometry::Region::dump(std::ofstream& of) const
+    std::ostream& operator<<(std::ostream& o, const StaticGeometry::Region& r)
     {
-        of << "Region " << mRegionID << std::endl;
-        of << "--------------------------" << std::endl;
-        of << "Centre: " << mCentre << std::endl;
-        of << "Local AABB: " << mAABB << std::endl;
-        of << "Bounding radius: " << mBoundingRadius << std::endl;
-        of << "Number of LODs: " << mLodBucketList.size() << std::endl;
+        o << "Region " << r.mRegionID << std::endl;
+        o << "--------------------------" << std::endl;
+        o << "Centre: " << r.mCentre << std::endl;
+        o << "Local AABB: " << r.mAABB << std::endl;
+        o << "Bounding radius: " << r.mBoundingRadius << std::endl;
+        o << "Number of LODs: " << r.mLodBucketList.size() << std::endl;
 
-        for (auto i : mLodBucketList)
+        for (auto i : r.mLodBucketList)
         {
-            i->dump(of);
+            o << *i;
         }
-        of << "--------------------------" << std::endl;
+        o << "--------------------------" << std::endl;
+        return o;
     }
     //--------------------------------------------------------------------------
     //--------------------------------------------------------------------------
@@ -1059,27 +1056,26 @@ namespace Ogre {
             mMaterialBucketMap.begin(), mMaterialBucketMap.end());
     }
     //--------------------------------------------------------------------------
-    void StaticGeometry::LODBucket::dump(std::ofstream& of) const
+    std::ostream& operator<<(std::ostream& o, const StaticGeometry::LODBucket& b)
     {
-        of << "LOD Bucket " << mLod << std::endl;
-        of << "------------------" << std::endl;
-        of << "LOD Value: " << mLodValue << std::endl;
-        of << "Number of Materials: " << mMaterialBucketMap.size() << std::endl;
-        for (const auto & i : mMaterialBucketMap)
+        o << "LOD Bucket " << b.mLod << std::endl;
+        o << "------------------" << std::endl;
+        o << "LOD Value: " << b.mLodValue << std::endl;
+        o << "Number of Materials: " << b.mMaterialBucketMap.size() << std::endl;
+        for (const auto & i : b.mMaterialBucketMap)
         {
-            i.second->dump(of);
+            o << *i.second;
         }
-        of << "------------------" << std::endl;
-
+        o << "------------------" << std::endl;
+        return o;
     }
     //---------------------------------------------------------------------
-    void StaticGeometry::LODBucket::visitRenderables(Renderable::Visitor* visitor, 
+    void StaticGeometry::LODBucket::visitRenderables(Renderable::Visitor* visitor,
         bool debugRenderables)
     {
-        for (MaterialBucketMap::const_iterator i = mMaterialBucketMap.begin();
-            i != mMaterialBucketMap.end(); ++i)
+        for (const auto& m : mMaterialBucketMap)
         {
-            i->second->visitRenderables(visitor, debugRenderables);
+            m.second->visitRenderables(visitor, debugRenderables);
         }
 
     }
@@ -1250,20 +1246,20 @@ namespace Ogre {
             mGeometryBucketList.begin(), mGeometryBucketList.end());
     }
     //--------------------------------------------------------------------------
-    void StaticGeometry::MaterialBucket::dump(std::ofstream& of) const
+    std::ostream& operator<<(std::ostream& o, const StaticGeometry::MaterialBucket& b)
     {
-        of << "Material Bucket " << getMaterialName() << std::endl;
-        of << "--------------------------------------------------" << std::endl;
-        of << "Geometry buckets: " << mGeometryBucketList.size() << std::endl;
-        for (auto i : mGeometryBucketList)
+        o << "Material Bucket " << b.getMaterialName() << std::endl;
+        o << "--------------------------------------------------" << std::endl;
+        o << "Geometry buckets: " << b.mGeometryBucketList.size() << std::endl;
+        for (auto i : b.mGeometryBucketList)
         {
-            i->dump(of);
+            o << *i;
         }
-        of << "--------------------------------------------------" << std::endl;
-
+        o << "--------------------------------------------------" << std::endl;
+        return o;
     }
     //---------------------------------------------------------------------
-    void StaticGeometry::MaterialBucket::visitRenderables(Renderable::Visitor* visitor, 
+    void StaticGeometry::MaterialBucket::visitRenderables(Renderable::Visitor* visitor,
         bool debugRenderables)
     {
         for (auto i : mGeometryBucketList)
@@ -1460,7 +1456,7 @@ namespace Ogre {
             // Copy indexes across with offset
             IndexData* srcIdxData = geom->geometry->indexData;
             HardwareBufferLockGuard srcIdxLock(srcIdxData->indexBuffer,
-                                               srcIdxData->indexStart * srcIdxData->indexBuffer->getIndexSize(), 
+                                               srcIdxData->indexStart * srcIdxData->indexBuffer->getIndexSize(),
                                                srcIdxData->indexCount * srcIdxData->indexBuffer->getIndexSize(),
                                                HardwareBuffer::HBL_READ_ONLY);
             if (indexType == HardwareIndexBuffer::IT_32BIT)
@@ -1574,17 +1570,17 @@ namespace Ogre {
         }
     }
     //--------------------------------------------------------------------------
-    void StaticGeometry::GeometryBucket::dump(std::ofstream& of) const
+    std::ostream& operator<<(std::ostream& o, const StaticGeometry::GeometryBucket& b)
     {
-        of << "Geometry Bucket" << std::endl;
-        of << "---------------" << std::endl;
-        of << "Geometry items: " << mQueuedGeometry.size() << std::endl;
-        of << "Vertex count: " << mVertexData->vertexCount << std::endl;
-        of << "Index count: " << mIndexData->indexCount << std::endl;
-        of << "---------------" << std::endl;
-
+        o << "Geometry Bucket" << std::endl;
+        o << "---------------" << std::endl;
+        o << "Geometry items: " << b.mQueuedGeometry.size() << std::endl;
+        o << "Vertex count: " << b.mVertexData->vertexCount << std::endl;
+        o << "Index count: " << b.mIndexData->indexCount << std::endl;
+        o << "---------------" << std::endl;
+        return o;
     }
     //--------------------------------------------------------------------------
-    String StaticGeometryFactory::FACTORY_TYPE_NAME = "StaticGeometry";
+    const String MOT_STATIC_GEOMETRY = "StaticGeometry";
 }
 
