@@ -331,8 +331,6 @@ String ReplaceSpaces(const String& s)
 }
 } // namespace
 
-int AssimpLoader::msBoneCount = 0;
-
 AssimpLoader::AssimpLoader()
 {
     Assimp::DefaultLogger::create("");
@@ -419,11 +417,9 @@ bool AssimpLoader::_load(const char* name, Assimp::Importer& importer, Mesh* mes
 
     if (mBonesByName.size())
     {
-        mSkeleton = SkeletonManager::getSingleton().create(basename + ".skeleton", RGN_DEFAULT, true);
+        mSkeleton = SkeletonManager::getSingleton().create(basename + ".skeleton", mesh->getGroup(), true);
 
-        msBoneCount = 0;
         createBonesFromNode(scene, scene->mRootNode);
-        msBoneCount = 0;
         createBoneHiearchy(scene, scene->mRootNode);
 
         if (scene->HasAnimations())
@@ -764,7 +760,7 @@ void AssimpLoader::createBonesFromNode(const aiScene* mScene, const aiNode* pNod
 {
     if (isNodeNeeded(pNode->mName.data))
     {
-        Bone* bone = mSkeleton->createBone(String(pNode->mName.data), msBoneCount);
+        Bone* bone = mSkeleton->createBone(String(pNode->mName.data));
 
         aiQuaternion rot;
         aiVector3D pos;
@@ -781,10 +777,9 @@ void AssimpLoader::createBonesFromNode(const aiScene* mScene, const aiNode* pNod
 
         if (!mQuietMode)
         {
-            LogManager::getSingleton().logMessage(StringConverter::toString(msBoneCount) +
+            LogManager::getSingleton().logMessage(StringConverter::toString(bone->getHandle()) +
                                                   ") Creating bone '" + String(pNode->mName.data) + "'");
         }
-        msBoneCount++;
     }
     // Traverse all child nodes of the current node instance
     for (unsigned int childIdx = 0; childIdx < pNode->mNumChildren; ++childIdx)
@@ -968,6 +963,13 @@ static MaterialPtr createMaterial(const aiMaterial* mat, const Ogre::String &gro
         LogManager::getSingleton().logMessage("Creating " + matName);
     }
 
+    aiString tmp;
+    String alphaMode;
+    if (AI_SUCCESS == aiGetMaterialString(mat, "$mat.gltf.alphaMode", 0, 0, &tmp))
+    {
+        alphaMode = String(tmp.data);
+    }
+
     // ambient
     aiColor4D clr(1.0f, 1.0f, 1.0f, 1.0);
     // Ambient is usually way too low! FIX ME!
@@ -982,6 +984,12 @@ static MaterialPtr createMaterial(const aiMaterial* mat, const Ogre::String &gro
         omat->setDiffuse(clr.r, clr.g, clr.b, clr.a);
     }
 
+    if (clr.a < 1.0f || alphaMode == "BLEND")
+    {
+        omat->setSceneBlending(SBT_TRANSPARENT_ALPHA);
+        omat->setDepthWriteEnabled(false);
+    }
+
     // specular
     clr = aiColor4D(1.0f, 1.0f, 1.0f, 1.0f);
     if (AI_SUCCESS == aiGetMaterialColor(mat, AI_MATKEY_COLOR_SPECULAR, &clr))
@@ -1022,6 +1030,12 @@ static MaterialPtr createMaterial(const aiMaterial* mat, const Ogre::String &gro
         }
     }
 
+    float alphaCutoff = 1.0f;
+    if (AI_SUCCESS == mat->Get("$mat.gltf.alphaCutoff", 0, 0, alphaCutoff) && alphaMode == "MASK")
+    {
+        omat->getTechnique(0)->getPass(0)->setAlphaRejectSettings(CMPF_GREATER, alphaCutoff * 255.0f);
+    }
+
     String basename;
     if (getTextureName(mat, type, scene, meshName, basename))
     {
