@@ -4,26 +4,25 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 octree.cpp  -  Slightly modified version of Octree.cpp from TerrainSM. 
 
@@ -32,18 +31,19 @@ begin                : Mon Sep 30 2002
 copyright            : (C) 2002 by Jon Anderson
 email                : janders@users.sf.net
 
-Enhancements 2003 - 2004 (C) The OGRE Team
 Modified to use with PCZones 2007 by Eric Cha
 -----------------------------------------------------------------------------
 */
 
-#include <OgreOctreeZoneOctree.h>
-#include <OgrePCZSceneNode.h>
+#include "OgreOctreeZoneOctree.h"
+#include "OgrePCZSceneNode.h"
 #include "OgreOctreeZone.h"
+#include "OgreRay.h"
+#include "OgreWireBoundingBox.h"
 
 namespace Ogre
 {
-
+    namespace {
     /* INTERSECTION UTILITY FUNCTIONS ***/
 
     enum Intersection
@@ -57,8 +57,8 @@ namespace Ogre
     {
         // Null box?
         if (two.isNull()) return OUTSIDE;
-	    // Infinite box?
-	    if (two.isInfinite()) return INTERSECT;
+        // Infinite box?
+        if (two.isInfinite()) return INTERSECT;
 
         bool inside = true;
         const Vector3& twoMin = two.getMinimum();
@@ -127,8 +127,8 @@ namespace Ogre
     {
         // Null box?
         if (two.isNull()) return OUTSIDE;
-	    // Infinite box?
-	    if (two.isInfinite()) return INTERSECT;
+        // Infinite box?
+        if (two.isInfinite()) return INTERSECT;
 
         // Get centre of the box
         Vector3 centre = two.getCenter();
@@ -167,8 +167,8 @@ namespace Ogre
     {
         // Null box?
         if (one.isNull() || two.isNull()) return OUTSIDE;
-	    if (one.isInfinite()) return INSIDE;
-	    if (two.isInfinite()) return INTERSECT;
+        if (one.isInfinite()) return INSIDE;
+        if (two.isInfinite()) return INTERSECT;
 
 
         const Vector3& insideMin = two.getMinimum();
@@ -207,7 +207,7 @@ namespace Ogre
     {
         // Null box?
         if (two.isNull()) return OUTSIDE;
-	    if (two.isInfinite()) return INTERSECT;
+        if (two.isInfinite()) return INTERSECT;
 
         float sradius = one.getRadius();
 
@@ -260,6 +260,7 @@ namespace Ogre
         }
 
 
+    }
     }
     /***************************************************/
 
@@ -267,9 +268,9 @@ namespace Ogre
     */
     bool Octree::_isTwiceSize( const AxisAlignedBox &box ) const
     {
-	    // infinite boxes never fit in a child - always root node
-	    if (box.isInfinite())
-		    return false;
+        // infinite boxes never fit in a child - always root node
+        if (box.isInfinite())
+            return false;
 
         Vector3 halfMBoxSize = mBox.getHalfSize();
         Vector3 boxSize = box.getSize();
@@ -283,9 +284,6 @@ namespace Ogre
     */
     void Octree::_getChildIndexes( const AxisAlignedBox &box, int *x, int *y, int *z ) const
     {
-        Vector3 max = mBox.getMaximum();
-        Vector3 min = box.getMinimum();
-
         Vector3 center = mBox.getMaximum().midPoint( mBox.getMinimum() );
 
         Vector3 ncenter = box.getMaximum().midPoint( box.getMinimum() );
@@ -322,7 +320,7 @@ namespace Ogre
                 }
             }
         }
-	    mZone = oz;
+        mZone = oz;
         mParent = parent;
         mNumNodes = 0;
     }
@@ -361,7 +359,7 @@ namespace Ogre
     void Octree::_removeNode( PCZSceneNode * n )
     {
         mNodes.erase(n);
-		((OctreeZoneData*)n ->getZoneData(mZone))->setOctant( 0 );
+        ((OctreeZoneData*)n ->getZoneData(mZone))->setOctant( 0 );
 
         //update total counts.
         _unref();
@@ -385,231 +383,231 @@ namespace Ogre
     void Octree::_findNodes(const AxisAlignedBox &t, 
                             PCZSceneNodeList &list, 
                             PCZSceneNode *exclude, 
-							bool includeVisitors,
+                            bool includeVisitors,
                             bool full )
     {
-	    if ( !full )
-	    {
-		    AxisAlignedBox obox;
-		    _getCullBounds( &obox );
+        if ( !full )
+        {
+            AxisAlignedBox obox;
+            _getCullBounds( &obox );
 
-		    Intersection isect = intersect( t, obox );
+            Intersection isect = intersect( t, obox );
 
-		    if ( isect == OUTSIDE )
-			    return ;
+            if ( isect == OUTSIDE )
+                return ;
 
-		    full = ( isect == INSIDE );
-	    }
+            full = ( isect == INSIDE );
+        }
 
 
-	    PCZSceneNodeList::iterator it = mNodes.begin();
+        PCZSceneNodeList::iterator it = mNodes.begin();
 
-	    while ( it != mNodes.end() )
-	    {
-		    PCZSceneNode * on = ( *it );
+        while ( it != mNodes.end() )
+        {
+            PCZSceneNode * on = ( *it );
 
-		    if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
-		    {
-			    if ( full )
-			    {
-					// make sure the node isn't already on the list
-					list.insert( on );
-			    }
+            if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
+            {
+                if ( full )
+                {
+                    // make sure the node isn't already on the list
+                    list.insert( on );
+                }
 
-			    else
-			    {
-				    Intersection nsect = intersect( t, on -> _getWorldAABB() );
+                else
+                {
+                    Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				    if ( nsect != OUTSIDE )
-				    {
-						// make sure the node isn't already on the list
-						list.insert( on );
-				    }
-			    }
+                    if ( nsect != OUTSIDE )
+                    {
+                        // make sure the node isn't already on the list
+                        list.insert( on );
+                    }
+                }
 
-		    }
-		    ++it;
-	    }
+            }
+            ++it;
+        }
 
-	    Octree* child;
+        Octree* child;
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
     }
 
     void Octree::_findNodes(const Ray &t, 
                             PCZSceneNodeList &list, 
                             PCZSceneNode *exclude, 
-							bool includeVisitors,
+                            bool includeVisitors,
                             bool full )
     {
-	    if ( !full )
-	    {
-		    AxisAlignedBox obox;
-		    _getCullBounds( &obox );
+        if ( !full )
+        {
+            AxisAlignedBox obox;
+            _getCullBounds( &obox );
 
-		    Intersection isect = intersect( t, obox );
+            Intersection isect = intersect( t, obox );
 
-		    if ( isect == OUTSIDE )
-			    return ;
+            if ( isect == OUTSIDE )
+                return ;
 
-		    full = ( isect == INSIDE );
-	    }
+            full = ( isect == INSIDE );
+        }
 
 
-	    PCZSceneNodeList::iterator it = mNodes.begin();
+        PCZSceneNodeList::iterator it = mNodes.begin();
 
-	    while ( it != mNodes.end() )
-	    {
-		    PCZSceneNode * on = ( *it );
+        while ( it != mNodes.end() )
+        {
+            PCZSceneNode * on = ( *it );
 
-		    if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
-		    {
-			    if ( full )
-			    {
-					// make sure the node isn't already on the list
-					list.insert( on );
-			    }
+            if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
+            {
+                if ( full )
+                {
+                    // make sure the node isn't already on the list
+                    list.insert( on );
+                }
 
-			    else
-			    {
-				    Intersection nsect = intersect( t, on -> _getWorldAABB() );
+                else
+                {
+                    Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				    if ( nsect != OUTSIDE )
-				    {
-						// make sure the node isn't already on the list
-						list.insert( on );
-				    }
-			    }
+                    if ( nsect != OUTSIDE )
+                    {
+                        // make sure the node isn't already on the list
+                        list.insert( on );
+                    }
+                }
 
-		    }
-		    ++it;
-	    }
+            }
+            ++it;
+        }
 
-	    Octree* child;
+        Octree* child;
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
     }
 
     void Octree::_findNodes(const Sphere &t, 
                             PCZSceneNodeList &list, 
                             PCZSceneNode *exclude, 
-							bool includeVisitors,
+                            bool includeVisitors,
                             bool full )
     {
-	    if ( !full )
-	    {
-		    AxisAlignedBox obox;
-		    _getCullBounds( &obox );
+        if ( !full )
+        {
+            AxisAlignedBox obox;
+            _getCullBounds( &obox );
 
-		    Intersection isect = intersect( t, obox );
+            Intersection isect = intersect( t, obox );
 
-		    if ( isect == OUTSIDE )
-			    return ;
+            if ( isect == OUTSIDE )
+                return ;
 
-		    full = ( isect == INSIDE );
-	    }
+            full = ( isect == INSIDE );
+        }
 
 
-	    PCZSceneNodeList::iterator it = mNodes.begin();
+        PCZSceneNodeList::iterator it = mNodes.begin();
 
-	    while ( it != mNodes.end() )
-	    {
-		    PCZSceneNode * on = ( *it );
+        while ( it != mNodes.end() )
+        {
+            PCZSceneNode * on = ( *it );
 
-		    if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
-		    {
-			    if ( full )
-			    {
-					// make sure the node isn't already on the list
-					list.insert( on );
-			    }
+            if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
+            {
+                if ( full )
+                {
+                    // make sure the node isn't already on the list
+                    list.insert( on );
+                }
 
-			    else
-			    {
-				    Intersection nsect = intersect( t, on -> _getWorldAABB() );
+                else
+                {
+                    Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				    if ( nsect != OUTSIDE )
-				    {
-						// make sure the node isn't already on the list
-						list.insert( on );
-				    }
-			    }
+                    if ( nsect != OUTSIDE )
+                    {
+                        // make sure the node isn't already on the list
+                        list.insert( on );
+                    }
+                }
 
-		    }
-		    ++it;
-	    }
+            }
+            ++it;
+        }
 
-	    Octree* child;
+        Octree* child;
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
     }
 
@@ -617,77 +615,77 @@ namespace Ogre
     void Octree::_findNodes(const PlaneBoundedVolume &t, 
                             PCZSceneNodeList &list, 
                             PCZSceneNode *exclude, 
-							bool includeVisitors,
+                            bool includeVisitors,
                             bool full )
     {
-	    if ( !full )
-	    {
-		    AxisAlignedBox obox;
-		    _getCullBounds( &obox );
+        if ( !full )
+        {
+            AxisAlignedBox obox;
+            _getCullBounds( &obox );
 
-		    Intersection isect = intersect( t, obox );
+            Intersection isect = intersect( t, obox );
 
-		    if ( isect == OUTSIDE )
-			    return ;
+            if ( isect == OUTSIDE )
+                return ;
 
-		    full = ( isect == INSIDE );
-	    }
+            full = ( isect == INSIDE );
+        }
 
 
-	    PCZSceneNodeList::iterator it = mNodes.begin();
+        PCZSceneNodeList::iterator it = mNodes.begin();
 
-	    while ( it != mNodes.end() )
-	    {
-		    PCZSceneNode * on = ( *it );
+        while ( it != mNodes.end() )
+        {
+            PCZSceneNode * on = ( *it );
 
-		    if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
-		    {
-			    if ( full )
-			    {
-					// make sure the node isn't already on the list
-					list.insert( on );
-			    }
+            if ( on != exclude && (on->getHomeZone() == mZone || includeVisitors ))
+            {
+                if ( full )
+                {
+                    // make sure the node isn't already on the list
+                    list.insert( on );
+                }
 
-			    else
-			    {
-				    Intersection nsect = intersect( t, on -> _getWorldAABB() );
+                else
+                {
+                    Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				    if ( nsect != OUTSIDE )
-				    {
-						// make sure the node isn't already on the list
-						list.insert( on );
-				    }
-			    }
+                    if ( nsect != OUTSIDE )
+                    {
+                        // make sure the node isn't already on the list
+                        list.insert( on );
+                    }
+                }
 
-		    }
-		    ++it;
-	    }
+            }
+            ++it;
+        }
 
-	    Octree* child;
+        Octree* child;
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
-	    if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		    child->_findNodes( t, list, exclude, includeVisitors, full );
+        if ( (child=mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+            child->_findNodes( t, list, exclude, includeVisitors, full );
 
     }
 
