@@ -50,7 +50,7 @@ namespace Ogre {
         is the angle across which to scatter the particles either side of the
         base direction of the emitter. 
     */
-    class _OgreParticleFXExport RingEmitter : public AreaEmitter
+    class RingEmitter : public AreaEmitter
     {
     public:
         /// @see AreaEmitter
@@ -58,21 +58,21 @@ namespace Ogre {
         class CmdInnerX : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for inner size (see ParamCommand).*/
         class CmdInnerY : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
 
         RingEmitter(ParticleSystem* psys);
 
         /// @see ParticleEmitter
-        void _initParticle(Particle* pParticle);
+        void _initParticle(Particle* pParticle) override;
 
         /** Sets the size of the clear space inside the area from where NO particles are emitted.
         @param x, y
