@@ -67,7 +67,6 @@ Sample_ShaderSystem::Sample_ShaderSystem() :
     mInstancedViewportsEnable = false;
     mInstancedViewportsSubRenderState = NULL;
     mInstancedViewportsFactory = NULL;
-    mBbsFlare = NULL;
     mAddedLotsOfModels = false;
     mNumberOfModelsAdded = 0;
     mCurrentBlendMode = NUM_BLEND_MODES - 1;
@@ -220,7 +219,12 @@ bool Sample_ShaderSystem::frameRenderingQueued( const FrameEvent& evt )
 //-----------------------------------------------------------------------
 void Sample_ShaderSystem::setupContent()
 {
-    
+    mTextureAtlasFactory.reset(new TextureAtlasSamplerFactory);
+    mShaderGenerator->addSubRenderStateFactory(mTextureAtlasFactory.get());
+
+    mInstancedViewportsFactory.reset(new ShaderExInstancedViewportsFactory);
+    mShaderGenerator->addSubRenderStateFactory(mInstancedViewportsFactory.get());
+
     // Setup default effects values.
     mCurLightingModel       = SSLM_PerPixelLighting;
     mPerPixelFogEnable      = false;
@@ -400,6 +404,11 @@ void Sample_ShaderSystem::setupUI()
 #ifdef RTSHADER_SYSTEM_BUILD_EXT_SHADERS
     mShadowMenu->addItem("PSSM 3");
     mShadowMenu->addItem("PSSM debug");
+
+    if(Root::getSingleton().getRenderSystem()->getCapabilities()->hasCapability(RSC_VP_RT_INDEX_ANY_SHADER))
+    {
+        mShadowMenu->addItem("PSSM3 SP");
+    }
 #endif
 
 
@@ -665,14 +674,6 @@ void Sample_ShaderSystem::createDirectionalLight()
     // create pivot node
     mDirectionalLightNode = mSceneMgr->getRootSceneNode()->createChildSceneNode();
     mDirectionalLightNode->setDirection(dir);
-
-    // Create billboard set.
-    mBbsFlare = mSceneMgr->createBillboardSet();
-    mBbsFlare->setMaterialName("Examples/Flare3");
-    mBbsFlare->createBillboard(-dir * 500.0)->setColour(light->getDiffuseColour());
-    mBbsFlare->setCastShadows(false);
-    
-    mDirectionalLightNode->attachObject(mBbsFlare);
     mDirectionalLightNode->attachObject(light);
 }
 
@@ -779,14 +780,10 @@ void Sample_ShaderSystem::updateInstancedViewports(bool enabled)
         if (mInstancedViewportsEnable)
         {
             mCamera->setCullingFrustum(&mInfiniteFrustum);
-
-            // having problems with bb...
-            mDirectionalLightNode->detachObject(mBbsFlare);
         }
         else
         {
             mCamera->setCullingFrustum(NULL);
-            mDirectionalLightNode->attachObject(mBbsFlare);
         }
 
 
@@ -859,7 +856,7 @@ void Sample_ShaderSystem::applyShadowType(int menuIndex)
         mSceneMgr->setShadowTechnique(SHADOWTYPE_NONE);
 
 #ifdef RTSHADER_SYSTEM_BUILD_EXT_SHADERS
-        if (auto srs = schemRenderState->getSubRenderState(SRS_INTEGRATED_PSSM3))
+        if (auto srs = schemRenderState->getSubRenderState(SRS_SHADOW_MAPPING))
         {
             schemRenderState->removeSubRenderState(srs);
         }
@@ -879,6 +876,8 @@ void Sample_ShaderSystem::applyShadowType(int menuIndex)
     // Integrated shadow PSSM with 3 splits.
     else if (menuIndex >= 1)
     {
+        auto casterMat = MaterialManager::getSingleton().getByName("PSSM/shadow_caster");
+        mSceneMgr->setShadowTextureCasterMaterial(casterMat);
         mSceneMgr->setShadowTechnique(SHADOWTYPE_TEXTURE_MODULATIVE_INTEGRATED);
         mSceneMgr->setShadowFarDistance(3000);
 
@@ -895,14 +894,6 @@ void Sample_ShaderSystem::applyShadowType(int menuIndex)
         mTrayMgr->removeWidgetFromTray(mDirLightCheckBox);
         mDirLightCheckBox->hide();
 
-        // Disable fog on the caster pass.
-        MaterialPtr passCaterMaterial = MaterialManager::getSingleton().getByName("PSSM/shadow_caster");
-        Pass* pssmCasterPass = passCaterMaterial->getTechnique(0)->getPass(0);
-        pssmCasterPass->setFog(true);
-
-        // Set up caster material - this is just a standard depth/shadow map caster
-        mSceneMgr->setShadowTextureCasterMaterial(passCaterMaterial);
-
         // shadow camera setup
         PSSMShadowCameraSetup* pssmSetup = new PSSMShadowCameraSetup();
         pssmSetup->calculateSplitPoints(3, mCamera->getNearClipDistance(), mSceneMgr->getShadowFarDistance());
@@ -914,9 +905,31 @@ void Sample_ShaderSystem::applyShadowType(int menuIndex)
         mSceneMgr->setShadowCameraSetup(ShadowCameraSetupPtr(pssmSetup));
 
     
-        auto subRenderState = mShaderGenerator->createSubRenderState(SRS_INTEGRATED_PSSM3);
+        auto subRenderState = mShaderGenerator->createSubRenderState(SRS_SHADOW_MAPPING);
         subRenderState->setParameter("split_points", pssmSetup->getSplitPoints());
-        subRenderState->setParameter("debug", menuIndex > 1);
+        subRenderState->setParameter("debug", menuIndex == 2);
+        subRenderState->setParameter("array_texture", menuIndex == 3);
+
+        if(menuIndex == 3)
+        {
+            mSceneMgr->setShadowTextureCount(1);
+            ShadowTextureConfig shadowTextureConfig;
+            shadowTextureConfig.format = PF_DEPTH16;
+            shadowTextureConfig.width = 512;
+            shadowTextureConfig.height = 512;
+            shadowTextureConfig.depth = 3;
+            shadowTextureConfig.type = TEX_TYPE_2D_ARRAY;
+            shadowTextureConfig.extraFlags = TU_TARGET_ALL_LAYERS;
+            mSceneMgr->setShadowTextureConfig(0, shadowTextureConfig);
+
+            auto vprtState= mShaderGenerator->createSubRenderState("SGX_InstancedViewports");
+            vprtState->setParameter("schemeName", Any(MSN_SHADOWCASTER));
+            vprtState->setParameter("layeredTarget", true);
+            vprtState->setParameter("viewportGrid", Vector2(3, 1));
+
+            auto casterRenderState = mShaderGenerator->getRenderState(MSN_SHADERGEN, *casterMat, 0);
+            casterRenderState->addTemplateSubRenderState(vprtState);
+        }
         schemRenderState->addTemplateSubRenderState(subRenderState);        
     }
 #endif
@@ -934,22 +947,23 @@ void Sample_ShaderSystem::testCapabilities( const RenderSystemCapabilities* caps
     OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "RTSS not supported on your system");
 }
 
-//-----------------------------------------------------------------------
-void Sample_ShaderSystem::loadResources()
-{
-    mTextureAtlasFactory = OGRE_NEW TextureAtlasSamplerFactory;
-    mShaderGenerator->addSubRenderStateFactory(mTextureAtlasFactory);
-}
-
 //-----------------------------------------------------------------------
 void Sample_ShaderSystem::unloadResources()
 {
-    if (mTextureAtlasFactory != NULL)
+    mShaderGenerator->removeAllShaderBasedTechniques("PSSM/shadow_caster");
+
+    if (mTextureAtlasFactory)
     {
         mTextureAtlasFactory->destroyAllInstances();
-        mShaderGenerator->removeSubRenderStateFactory(mTextureAtlasFactory);
-        OGRE_DELETE mTextureAtlasFactory;
-        mTextureAtlasFactory = NULL;
+        mShaderGenerator->removeSubRenderStateFactory(mTextureAtlasFactory.get());
+        mTextureAtlasFactory.reset();
+    }
+
+    if (mInstancedViewportsFactory)
+    {
+        mInstancedViewportsFactory->destroyAllInstances();
+        mShaderGenerator->removeSubRenderStateFactory(mInstancedViewportsFactory.get());
+        mInstancedViewportsFactory.reset();
     }
 }
 
@@ -1096,41 +1110,40 @@ void Sample_ShaderSystem::destroyInstancedViewports()
     mShaderGenerator->invalidateScheme(Ogre::MSN_SHADERGEN);
     mShaderGenerator->validateScheme(Ogre::MSN_SHADERGEN);
 
-    destroyInstancedViewportsFactory();
-
-}
-//-----------------------------------------------------------------------
-void Sample_ShaderSystem::destroyInstancedViewportsFactory()
-{
-    if (mInstancedViewportsFactory != NULL)
+    for (int i = 0; i < 3; i++)
     {
-        mInstancedViewportsFactory->destroyAllInstances();
-        mShaderGenerator->removeSubRenderStateFactory(mInstancedViewportsFactory);
-        delete mInstancedViewportsFactory;
-        mInstancedViewportsFactory = NULL;
+        mSceneMgr->destroyCamera(StringUtil::format("InstancedCamera%d", i));
     }
 }
 //-----------------------------------------------------------------------
 
 void Sample_ShaderSystem::createInstancedViewports()
 {
-    if (mInstancedViewportsFactory == NULL)
+    if (Root::getSingletonPtr()->getRenderSystem()->getName().find("Direct3D9") != String::npos)
     {
-        mInstancedViewportsFactory = OGRE_NEW ShaderExInstancedViewportsFactory;    
-        mShaderGenerator->addSubRenderStateFactory(mInstancedViewportsFactory);
+        mSceneMgr->getManualObject("TextureAtlasObject")->getParentSceneNode()->setVisible(false);
+        mSceneMgr->setSkyBox(false, "");
     }
 
-    Ogre::Vector2 monitorCount(2.0, 2.0);
-    mInstancedViewportsSubRenderState = mShaderGenerator->createSubRenderState<RTShader::ShaderExInstancedViewports>();
-    Ogre::RTShader::ShaderExInstancedViewports* shaderExInstancedViewports 
-        = static_cast<Ogre::RTShader::ShaderExInstancedViewports*>(mInstancedViewportsSubRenderState);
-    shaderExInstancedViewports->setMonitorsCount(monitorCount);
+    std::vector<const Camera*> cameras = {mCamera};
+    for (int i = 0; i < 3; i++)
+    {
+        auto cam = mSceneMgr->createCamera(StringUtil::format("InstancedCamera%d", i));
+        auto node = mCamera->getParentSceneNode()->createChildSceneNode();
+        node->yaw(Degree(i * 90 - 45));
+        node->attachObject(cam);
+        cameras.push_back(cam);
+    }
+
+    mSceneMgr->setVPRTCameras(cameras);
+
+    mInstancedViewportsSubRenderState = mShaderGenerator->createSubRenderState("SGX_InstancedViewports");
+    mInstancedViewportsSubRenderState->setParameter("viewportGrid", Vector2(2, 2));
     Ogre::RTShader::RenderState* renderState = mShaderGenerator->getRenderState(Ogre::MSN_SHADERGEN);
     renderState->addTemplateSubRenderState(mInstancedViewportsSubRenderState);
 
     // Invalidate the scheme in order to re-generate all shaders based technique related to this scheme.
     mShaderGenerator->invalidateScheme(Ogre::MSN_SHADERGEN);
-    mShaderGenerator->validateScheme(Ogre::MSN_SHADERGEN);
 }
 
 void Sample_ShaderSystem::createMaterialForTexture( const String & texName, bool isTextureAtlasTexture )
